NXSDataWriter Tango Class Description

NXSDataWriter Class Identification : | NXSDataWriter Class Inheritance :
Contact | : at desy.de - jan.kotanski
Class Family | : Acquisition
Platform | : All Platforms
Bus | : Not Applicable
Manufacturer | : DESY
Manufacturer ref. | :
| Tango::DeviceImpl NXSDataWriter

NXSDataWriter Class Description :

NXSDataWriter is a Tango server which allows to store NeXuS Data in H5 files.
The server provides storing data from other Tango devices,
various databases as well as passed by a user client via JSON strings.
Source code: https://github.com/nexdatas/nxsdatawriter
Project Web page: https://nexdatas.github.io/nxsdatawriter
NexDaTaS Web page: https://nexdatas.github.io